# velorail
Multimodal bike and train route planning support

[![pypi](https://img.shields.io/pypi/pyversions/velorail)](https://pypi.org/project/velorail/)
[![Github Actions Build](https://github.com/WolfgangFahl/velorail/actions/workflows/build.yml/badge.svg)](https://github.com/WolfgangFahl/velorail/actions/workflows/build.yml)
[![PyPI Status](https://img.shields.io/pypi/v/velorail.svg)](https://pypi.python.org/pypi/velorail/)
[![GitHub issues](https://img.shields.io/github/issues/WolfgangFahl/velorail.svg)](https://github.com/WolfgangFahl/velorail/issues)
[![GitHub closed issues](https://img.shields.io/github/issues-closed/WolfgangFahl/velorail.svg)](https://github.com/WolfgangFahl/velorail/issues/?q=is%3Aissue+is%3Aclosed)
[![API Docs](https://img.shields.io/badge/API-Documentation-blue)](https://WolfgangFahl.github.io/velorail/)

[![License](https://img.shields.io/github/license/WolfgangFahl/velorail.svg)](https://www.apache.org/licenses/LICENSE-2.0)

# Demo
[velorail](https://velorail.bitplan.com)

# Documentation
[wiki](https://wiki.bitplan.com/index.php/Velorail)